@@ -364,19 +364,19 @@ def get_features(df_data,
                                                      dm = 0,
                                                      ndim = embedding_dim)
             
-            doc_sim_features = RelationalDocs(ndim = embedding_dim)
+            doc_sim_features = RelationalDocs(ndim = embedding_dim, targets = targets)
             
             neural_features = [
                 ('neural_features_v1',
-                 pipeline.Pipeline([('s6', text_col(key='no_stopwords')),
+                 pipeline.Pipeline([('s6', text_col(key = 'no_stopwords')),
                                     ('sentence_embedding_mean',
                                      sentence_embedder_dm1)])) ,
                 ('neural_features_v2',
-                 pipeline.Pipeline([('s7', text_col(key='no_stopwords')),
+                 pipeline.Pipeline([('s7', text_col(key = 'no_stopwords')),
                                     ('sentence_embedding_mean',
                                      sentence_embedder_dm2)])),
                 ('doc_graph',
-                 pipeline.Pipeline([('s5', text_col(key='no_stopwords')),
+                 pipeline.Pipeline([('s5', text_col(key = 'no_stopwords')),
                                     ('doc_similarity_features', doc_sim_features)]))
             ]
             
@@ -422,14 +422,17 @@ def get_features(df_data,
                  pipeline.Pipeline([('s4', text_col(key='no_stopwords')),
                                     ('relational_features_unigram',
                                      lr_rel_features_unigram)])),
+                ('keyword_features',
+                 pipeline.Pipeline([('s5', text_col(key='no_stopwords')),
+                                    ('keyword_features', keyword_features)])),
                 ('relational_features_token',
                  pipeline.Pipeline([('s4', text_col(key='no_stopwords')),
                                     ('relational_features_token',
-                                     lr_rel_features_token)])),
-                ('keyword_features',
-                 pipeline.Pipeline([('s5', text_col(key='no_stopwords')),
-                                    ('keyword_features', keyword_features)]))
+                                     lr_rel_features_token)]))
             ]
+
+            if "neurosymbolic-default" in representation_type:
+                symbolic_features.pop()
             
             if concept_features:
                 concept_features = ConceptFeatures(max_features=max_num_feat,
@@ -444,7 +447,7 @@ def get_features(df_data,
         if representation_type == "symbolic":
             features = symbolic_features
 
-        elif representation_type == "neurosymbolic":
+        elif "neurosymbolic" in representation_type:
             features = symbolic_features + neural_features
 
         else:
